#ifndef NT2_INCLUDE_CONSTANTS_VALMAX_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_VALMAX_HPP_INCLUDED

#include <nt2/constant/include/constants/valmax.hpp>

#endif
